==> tree-component-3.2.0.tgz: package/react.js <==
"use strict";
import * as tslib_1 from "tslib";
import * as React from "react";
import * as common from "./common";
export * from "./common";
var Node = (function (_super) {
    tslib_1.__extends(Node, _super);
    function Node() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.hovered = false;
        _this.doubleClick = new common.DoubleClick();
        _this.contextmenuVisible = false;
        _this.contextmenuStyle = {
            position: "absolute",
            left: "0px",
            top: "0px",
            zIndex: typeof _this.props.zindex === "number" ? _this.props.zindex : 1,
        };
        return _this;
    }
    Node.prototype.render = function () {
        var _this = this;
        var childrenElement;
        if (this.props.data.children) {
            var nodesElement = this.props.data.children.map(function (child, i) { return (React.createElement(Node, { data: child, key: i, last: i === _this.props.data.children.length - 1, checkbox: _this.props.checkbox, path: _this.geChildPath(i), draggable: _this.props.draggable, root: _this.props.root, parent: _this, zindex: _this.props.zindex, preid: _this.props.preid, toggle: function (eventData) { return _this.ontoggle(eventData); }, change: function (eventData) { return _this.onchange(eventData); } })); });
            childrenElement = (React.createElement("ul", { role: "group", className: "tree-children" }, nodesElement));
        }
        else {
            childrenElement = null;
        }
        var checkboxElement = this.props.checkbox ? React.createElement("i", { className: this.checkboxClassName, role: "presentation" }) : null;
        var iconElement = this.props.data.icon !== false ? React.createElement("i", { className: this.iconClassName, role: "presentation" }) : null;
        var markerElement = this.hasMarker ? React.createElement("span", { className: this.markerClassName }, "\u00A0") : null;
        var contextmenu = this.props.data.contextmenu && this.contextmenuVisible ? React.createElement(this.props.data.contextmenu, { data: this.contextmenuData }) : null;
        return (React.createElement("li", { role: "treeitem", className: this.nodeClassName, id: this.id },
            React.createElement("i", { className: "tree-icon tree-ocl", role: "presentation", onClick: function () { return _this.ontoggle(); } }),
            React.createElement("a", { className: this.anchorClassName, href: "javascript:void(0)", draggable: this.props.draggable, onClick: function () { return _this.onchange(); }, onDoubleClick: function () { return _this.ontoggle(); }, onMouseEnter: function () { return _this.hover(true); }, onMouseLeave: function () { return _this.hover(false); }, onContextMenu: function (e) { return _this.oncontextmenu(e); }, "data-path": this.pathString },
                checkboxElement,
                iconElement,
                this.props.data.text,
                markerElement,
                React.createElement("div", { style: this.contextmenuStyle }, contextmenu)),
            childrenElement));
    };
    Object.defineProperty(Node.prototype, "nodeClassName", {
        get: function () {
            return common.getNodeClassName(this.props.data, this.props.last);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "anchorClassName", {
        get: function () {
            return common.getAnchorClassName(this.props.data, this.hovered);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "checkboxClassName", {
        get: function () {
            return common.getCheckboxClassName(this.props.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "iconClassName", {
        get: function () {
            return common.getIconClassName(this.props.data.icon);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "pathString", {
        get: function () {
            return this.props.path.toString();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "hasMarker", {
        get: function () {
            return this.props.draggable && this.props.data.state.dropPosition !== 0 /* empty */;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "markerClassName", {
        get: function () {
            return common.getMarkerClassName(this.props.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "eventData", {
        get: function () {
            return {
                data: this.props.data,
                path: this.props.path,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "contextmenuData", {
        get: function () {
            return {
                data: this.props.data,
                path: this.props.path,
                root: this.props.root,
                parent: this.props.parent,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "id", {
        get: function () {
            return common.getId(this.props.path, this.props.preid);
        },
        enumerable: true,
        configurable: true
    });
    Node.prototype.geChildPath = function (index) {
        return this.props.path.concat(index);
    };
    Node.prototype.hover = function (hovered) {
        this.hovered = hovered;
        this.setState({ hovered: this.hovered });
        if (!hovered) {
            this.contextmenuVisible = false;
            this.setState({ contextmenuVisible: this.contextmenuVisible });
        }
    };
    Node.prototype.ontoggle = function (eventData) {
        if (eventData) {
            this.props.toggle(eventData);
        }
        else {
            if (this.props.data.state.openable || this.props.data.children.length > 0) {
                this.props.toggle(this.eventData);
            }
        }
    };
    Node.prototype.onchange = function (eventData) {
        var _this = this;
        if (eventData) {
            this.props.change(eventData);
        }
        else {
            if (this.props.data.state.disabled) {
                return;
            }
            this.doubleClick.onclick(function () {
                _this.props.change(_this.eventData);
            });
        }
    };
    Node.prototype.oncontextmenu = function (e) {
        this.contextmenuVisible = true;
        this.contextmenuStyle.left = e.nativeEvent.offsetX + "px";
        this.contextmenuStyle.top = e.nativeEvent.offsetY + "px";
        this.setState({ contextmenuVisible: this.contextmenuVisible, contextmenuStyle: this.contextmenuStyle });
        e.preventDefault();
        return false;
    };
    return Node;
}(React.PureComponent));
var Tree = (function (_super) {
    tslib_1.__extends(Tree, _super);
    function Tree() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.dragTarget = null;
        _this.dropTarget = null;
        return _this;
    }
    Tree.prototype.render = function () {
        var _this = this;
        var childrenElement = this.props.data.map(function (child, i) { return (React.createElement(Node, { data: child, key: i, last: i === _this.props.data.length - 1, checkbox: _this.props.checkbox, path: [i], draggable: _this.props.draggable, root: _this.props.data, parent: _this, zindex: _this.props.zindex, preid: _this.props.preid, toggle: function (data) { return _this.ontoggle(data); }, change: function (data) { return _this.onchange(data); } })); });
        return (React.createElement("div", { className: this.rootClassName, role: "tree" },
            React.createElement("ul", { className: this.containerClassName, role: "group", onDragStart: function (eventData) { return _this.ondragstart(eventData); }, onDragEnd: function (eventData) { return _this.ondragend(eventData); }, onDragOver: function (eventData) { return _this.ondragover(eventData); }, onDragEnter: function (eventData) { return _this.ondragenter(eventData); }, onDragLeave: function (eventData) { return _this.ondragleave(eventData); }, onDrop: function (eventData) { return _this.ondrop(eventData); } }, childrenElement)));
    };
    Object.defineProperty(Tree.prototype, "rootClassName", {
        get: function () {
            return common.getRootClassName(this.props.checkbox, this.props.size, this.props.theme);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "containerClassName", {
        get: function () {
            return common.getContainerClassName(this.props.nodots);
        },
        enumerable: true,
        configurable: true
    });
    Tree.prototype.canDrop = function (event) {
        return this.props.draggable && event.target && event.target.dataset && event.target.dataset.path;
    };
    Tree.prototype.ontoggle = function (eventData) {
        if (this.props.toggle) {
            this.props.toggle(eventData);
        }
    };
    Tree.prototype.onchange = function (eventData) {
        if (this.props.change) {
            this.props.change(eventData);
        }
    };
    Tree.prototype.ondragstart = function (event) {
        if (!this.props.draggable) {
            return;
        }
        this.dragTarget = event.target;
        this.dropTarget = event.target;
        this.setState({ dragTarget: this.dragTarget, dropTarget: this.dropTarget });
    };
    Tree.prototype.ondragend = function (event) {
        if (!this.props.draggable) {
            return;
        }
        this.dragTarget = null;
        for (var _i = 0, _a = this.props.data; _i < _a.length; _i++) {
            var tree = _a[_i];
            common.clearMarkerOfTree(tree);
        }
        this.setState({ dragTarget: this.dragTarget });
    };
    Tree.prototype.ondragover = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.props.data, this.props.dropAllowed, function () { return _this.forceUpdate(); });
        event.preventDefault();
    };
    Tree.prototype.ondragenter = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        this.dropTarget = event.target;
        this.setState({ dropTarget: this.dropTarget });
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.props.data, this.props.dropAllowed, function () { return _this.forceUpdate(); });
    };
    Tree.prototype.ondragleave = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        if (event.target === this.dropTarget) {
            this.dropTarget = null;
        }
        this.setState({ dropTarget: this.dropTarget });
        common.ondragleave(event.target, this.props.data);
    };
    Tree.prototype.ondrop = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrop(event.target, this.dragTarget, this.props.data, function (dropData) {
            if (_this.props.drop) {
                _this.props.drop(dropData);
            }
        });
    };
    return Tree;
}(React.PureComponent));
export { Tree };

==> tree-component-3.3.0.tgz: package/react.js <==
"use strict";
import * as tslib_1 from "tslib";
import * as React from "react";
import * as common from "./common";
export * from "./common";
/**
 * @public
 */
var Node = /** @class */ (function (_super) {
    tslib_1.__extends(Node, _super);
    function Node() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.hovered = false;
        _this.doubleClick = new common.DoubleClick();
        _this.contextmenuVisible = false;
        _this.contextmenuStyle = {
            position: "absolute",
            left: "0px",
            top: "0px",
            zIndex: typeof _this.props.zindex === "number" ? _this.props.zindex : 1,
        };
        return _this;
    }
    Node.prototype.render = function () {
        var _this = this;
        var childrenElement;
        if (this.props.data.children) {
            var nodesElement = this.props.data.children.map(function (child, i) { return (React.createElement(Node, { data: child, key: i, last: i === _this.props.data.children.length - 1, checkbox: _this.props.checkbox, path: _this.geChildPath(i), draggable: _this.props.draggable, root: _this.props.root, parent: _this, zindex: _this.props.zindex, preid: _this.props.preid, toggle: function (eventData) { return _this.ontoggle(eventData); }, change: function (eventData) { return _this.onchange(eventData); } })); });
            childrenElement = (React.createElement("ul", { role: "group", className: "tree-children" }, nodesElement));
        }
        else {
            childrenElement = null;
        }
        var checkboxElement = this.props.checkbox ? React.createElement("i", { className: this.checkboxClassName, role: "presentation" }) : null;
        var iconElement = this.props.data.icon !== false ? React.createElement("i", { className: this.iconClassName, role: "presentation" }) : null;
        var markerElement = this.hasMarker ? React.createElement("span", { className: this.markerClassName }, "\u00A0") : null;
        var contextmenu = this.props.data.contextmenu && this.contextmenuVisible ? React.createElement(this.props.data.contextmenu, { data: this.contextmenuData }) : null;
        var text = this.props.data.component ? React.createElement(this.props.data.component, { data: this.props.data }) : this.props.data.text;
        return (React.createElement("li", { role: "treeitem", className: this.nodeClassName, id: this.id },
            React.createElement("i", { className: "tree-icon tree-ocl", role: "presentation", onClick: function () { return _this.ontoggle(); } }),
            React.createElement("a", { className: this.anchorClassName, href: "javascript:void(0)", draggable: this.props.draggable, onClick: function () { return _this.onchange(); }, onDoubleClick: function () { return _this.ontoggle(); }, onMouseEnter: function () { return _this.hover(true); }, onMouseLeave: function () { return _this.hover(false); }, onContextMenu: function (e) { return _this.oncontextmenu(e); }, "data-path": this.pathString },
                checkboxElement,
                iconElement,
                text,
                markerElement,
                React.createElement("div", { style: this.contextmenuStyle }, contextmenu)),
            childrenElement));
    };
    Object.defineProperty(Node.prototype, "nodeClassName", {
        get: function () {
            return common.getNodeClassName(this.props.data, this.props.last);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "anchorClassName", {
        get: function () {
            return common.getAnchorClassName(this.props.data, this.hovered);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "checkboxClassName", {
        get: function () {
            return common.getCheckboxClassName(this.props.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "iconClassName", {
        get: function () {
            return common.getIconClassName(this.props.data.icon);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "pathString", {
        get: function () {
            return this.props.path.toString();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "hasMarker", {
        get: function () {
            return this.props.draggable && this.props.data.state.dropPosition !== 0 /* empty */;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "markerClassName", {
        get: function () {
            return common.getMarkerClassName(this.props.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "eventData", {
        get: function () {
            return {
                data: this.props.data,
                path: this.props.path,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "contextmenuData", {
        get: function () {
            return {
                data: this.props.data,
                path: this.props.path,
                root: this.props.root,
                parent: this.props.parent,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "id", {
        get: function () {
            return common.getId(this.props.path, this.props.preid);
        },
        enumerable: true,
        configurable: true
    });
    Node.prototype.geChildPath = function (index) {
        return this.props.path.concat(index);
    };
    Node.prototype.hover = function (hovered) {
        this.hovered = hovered;
        this.setState({ hovered: this.hovered });
        if (!hovered) {
            this.contextmenuVisible = false;
            this.setState({ contextmenuVisible: this.contextmenuVisible });
        }
    };
    Node.prototype.ontoggle = function (eventData) {
        if (eventData) {
            this.props.toggle(eventData);
        }
        else {
            if (this.props.data.state.openable || this.props.data.children.length > 0) {
                this.props.toggle(this.eventData);
            }
        }
    };
    Node.prototype.onchange = function (eventData) {
        var _this = this;
        if (eventData) {
            this.props.change(eventData);
        }
        else {
            if (this.props.data.state.disabled) {
                return;
            }
            this.doubleClick.onclick(function () {
                _this.props.change(_this.eventData);
            });
        }
    };
    Node.prototype.oncontextmenu = function (e) {
        this.contextmenuVisible = true;
        this.contextmenuStyle.left = e.nativeEvent.offsetX + "px";
        this.contextmenuStyle.top = e.nativeEvent.offsetY + "px";
        this.setState({ contextmenuVisible: this.contextmenuVisible, contextmenuStyle: this.contextmenuStyle });
        e.preventDefault();
        return false;
    };
    return Node;
}(React.PureComponent));
/**
 * @public
 */
var Tree = /** @class */ (function (_super) {
    tslib_1.__extends(Tree, _super);
    function Tree() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.dragTarget = null;
        _this.dropTarget = null;
        return _this;
    }
    Tree.prototype.render = function () {
        var _this = this;
        var childrenElement = this.props.data.map(function (child, i) { return (React.createElement(Node, { data: child, key: i, last: i === _this.props.data.length - 1, checkbox: _this.props.checkbox, path: [i], draggable: _this.props.draggable, root: _this.props.data, parent: _this, zindex: _this.props.zindex, preid: _this.props.preid, toggle: function (data) { return _this.ontoggle(data); }, change: function (data) { return _this.onchange(data); } })); });
        return (React.createElement("div", { className: this.rootClassName, role: "tree" },
            React.createElement("ul", { className: this.containerClassName, role: "group", onDragStart: function (eventData) { return _this.ondragstart(eventData); }, onDragEnd: function (eventData) { return _this.ondragend(eventData); }, onDragOver: function (eventData) { return _this.ondragover(eventData); }, onDragEnter: function (eventData) { return _this.ondragenter(eventData); }, onDragLeave: function (eventData) { return _this.ondragleave(eventData); }, onDrop: function (eventData) { return _this.ondrop(eventData); } }, childrenElement)));
    };
    Object.defineProperty(Tree.prototype, "rootClassName", {
        get: function () {
            return common.getRootClassName(this.props.checkbox, this.props.size, this.props.theme);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "containerClassName", {
        get: function () {
            return common.getContainerClassName(this.props.nodots);
        },
        enumerable: true,
        configurable: true
    });
    Tree.prototype.canDrop = function (event) {
        return this.props.draggable && event.target && event.target.dataset && event.target.dataset.path;
    };
    Tree.prototype.ontoggle = function (eventData) {
        if (this.props.toggle) {
            this.props.toggle(eventData);
        }
    };
    Tree.prototype.onchange = function (eventData) {
        if (this.props.change) {
            this.props.change(eventData);
        }
    };
    Tree.prototype.ondragstart = function (event) {
        if (!this.props.draggable) {
            return;
        }
        this.dragTarget = event.target;
        this.dropTarget = event.target;
        this.setState({ dragTarget: this.dragTarget, dropTarget: this.dropTarget });
    };
    Tree.prototype.ondragend = function (event) {
        if (!this.props.draggable) {
            return;
        }
        this.dragTarget = null;
        for (var _i = 0, _a = this.props.data; _i < _a.length; _i++) {
            var tree = _a[_i];
            common.clearMarkerOfTree(tree);
        }
        this.setState({ dragTarget: this.dragTarget });
    };
    Tree.prototype.ondragover = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.props.data, this.props.dropAllowed, function () { return _this.forceUpdate(); });
        event.preventDefault();
    };
    Tree.prototype.ondragenter = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        this.dropTarget = event.target;
        this.setState({ dropTarget: this.dropTarget });
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.props.data, this.props.dropAllowed, function () { return _this.forceUpdate(); });
    };
    Tree.prototype.ondragleave = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        if (event.target === this.dropTarget) {
            this.dropTarget = null;
        }
        this.setState({ dropTarget: this.dropTarget });
        common.ondragleave(event.target, this.props.data);
    };
    Tree.prototype.ondrop = function (event) {
        var _this = this;
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrop(event.target, this.dragTarget, this.props.data, function (dropData) {
            if (_this.props.drop) {
                _this.props.drop(dropData);
            }
        });
    };
    return Tree;
}(React.PureComponent));
export { Tree };
